@@ -168,8 +168,8 @@ if args.run in ['run', 'Run', 'RUN']:
         from algo_trader.strategies import Lotus
         from algo_trader.clients import BitmexClient
 
-        client = BitmexClient(api_key=start_settings.api_key, api_secret=start_settings.api_secret, test=testnet)
-        lotus = Lotus(client, symbols, token=start_settings.token, pos_size=start_settings.position_size, testnet=testnet, settings_file_name=setting_file_name)
+        client = BitmexClient(api_key=start_settings.api_key, api_secret=start_settings.api_secret, testnet=testnet)
+        lotus = Lotus(client, symbols, start_settings, setting_file_name=setting_file_name)
         lotus.run()
     
     """
